# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Printing, Utils

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2

class AddInAttribute(
    System.Runtime.InteropServices._Attribute, System.Attribute
):  # Class
    def __init__(self, applicationName: str, addInType: System.Type) -> None: ...

    AddInType: System.Type  # readonly
    ApplicationName: str  # readonly

class AddInConfigurationElement:  # Class
    Enabled: bool
    IsScript: bool  # readonly
    PathName: str  # readonly
    Type: str  # readonly

    def Equals(
        self,
        element: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInConfigurationElement,
    ) -> bool: ...
    def Clone(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInConfigurationElement
    ): ...

class AddInConfigurationSection(System.Configuration.ConfigurationSection):  # Class
    def __init__(self) -> None: ...

    Count: int  # readonly
    def __getitem__(
        self, index: int
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInConfigurationElement
    ): ...
    def Contains(self, pathName: str, type: str, isScript: bool) -> bool: ...
    def GetElement(
        self, pathName: str, type: str, isScript: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInConfigurationElement
    ): ...
    def Add(
        self, pathName: str, type: str, isScript: bool
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInConfigurationElement
    ): ...

class AddInManager(System.IDisposable):  # Class
    def __init__(self, state: Any) -> None: ...

    AddInsTabID: str = ...  # static # readonly

    Count: int  # readonly
    RibbonSharedRibbonTabCaption: str  # static # readonly
    State: Any  # readonly

    def Contains(self, id: str) -> bool: ...
    def GetScriptEngine(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.IAddInScriptEngine
    ): ...
    def GetType(self, id: str) -> str: ...
    def IsEnabled(self, id: str) -> bool: ...
    def GetAddIn(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.IAddIn: ...
    @staticmethod
    def GetAddInID(pathName: str, type: str) -> str: ...
    def LoadScript(self, scriptPath: str) -> None: ...
    def CreateScriptAddin(
        self, pathName: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.IAddIn: ...
    def Clear(self) -> None: ...
    def Enable(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.IAddIn: ...
    def GetPathName(self, id: str) -> str: ...
    def LoadAssembly(self, assemblyPath: str, appName: str) -> int: ...
    def Dispose(self) -> None: ...
    def GetIDs(self) -> List[str]: ...
    def Disable(self, id: str) -> None: ...
    def IsScript(self, id: str) -> bool: ...

class ConfigurationArrayElement(
    Generic[T], System.Xml.Serialization.IXmlSerializable
):  # Class
    Count: int  # readonly
    def __getitem__(self, index: int) -> T: ...
    def __setitem__(self, index: int, value_: T) -> None: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self,
        element: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationArrayElement,
    ) -> bool: ...
    def Add(self, t: T) -> None: ...
    def Clear(self) -> None: ...
    def AddRange(self, e: Iterable[T]) -> None: ...
    def GetHashCode(self) -> int: ...
    def GetSchema(self) -> System.Xml.Schema.XmlSchema: ...
    def WriteXml(self, writer: System.Xml.XmlWriter) -> None: ...
    def ReadXml(self, reader: System.Xml.XmlReader) -> None: ...
    def SetArray(self, array: List[T]) -> None: ...
    def ToArray(self) -> List[T]: ...

class ConfigurationColorArrayElement(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationArrayElement[
        System.Drawing.Color
    ],
    System.Xml.Serialization.IXmlSerializable,
):  # Class
    def __init__(self) -> None: ...

class ConfigurationElementSectionBase(
    System.Configuration.ConfigurationSection
):  # Class
    def __init__(self) -> None: ...

class ConfigurationStringArrayElement(
    System.Xml.Serialization.IXmlSerializable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationArrayElement[
        str
    ],
):  # Class
    def __init__(self) -> None: ...

class ControlHelpMap(System.IDisposable):  # Class
    @overload
    def __init__(
        self, control: System.Windows.Forms.Control, helpFile: str, helpId: int
    ) -> None: ...
    @overload
    def __init__(
        self, dialog: System.Windows.Forms.CommonDialog, helpFile: str, helpId: int
    ) -> None: ...

    HelpId: int  # readonly

    def Dispose(self) -> None: ...
    def ShowHelp(self) -> None: ...

class ControlHtmlHelpMap(System.IDisposable):  # Class
    def __init__(
        self,
        control: System.Windows.Forms.Control,
        root: str,
        subfolder: str,
        html: str,
        topic: str,
    ) -> None: ...
    def Dispose(self) -> None: ...
    def ShowHelp(self) -> None: ...

class DelayDeleteFile:  # Class
    def __init__(self, file: str) -> None: ...

class EnumItem(Generic[T]):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, t: T, displayText: str) -> None: ...

    DisplayText: str  # readonly
    Value: T  # readonly

    def ToString(self) -> str: ...

class GridUtils:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def SetVisibleColumns(
        view: System.Windows.Forms.DataGridView, columns: List[str]
    ) -> None: ...

class HelpUtils:  # Class
    @staticmethod
    def ShowHtmlHelp(
        helproot: str, subfolder: str, htmlfile: str, topic: str
    ) -> bool: ...
    @staticmethod
    def GetLastTimeHelpLaunched() -> System.DateTime: ...

    # Nested Types

    class ActivateOptions(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        DesignMode: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.HelpUtils.ActivateOptions
        ) = ...  # static # readonly
        NoErrorUI: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.HelpUtils.ActivateOptions
        ) = ...  # static # readonly
        NoSplashScreen: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.HelpUtils.ActivateOptions
        ) = ...  # static # readonly

class IAddIn(object):  # Interface
    DisplayName: str  # readonly
    Enabled: bool  # readonly

    def Uninitialize(self, state: Any) -> None: ...
    def Initialize(self, state: Any) -> None: ...
    def Execute(self, parameters: List[Any]) -> Any: ...

class IAddInScriptEngine(object):  # Interface
    def ExecuteFile(self, file: str) -> Any: ...

class IdleDetector(System.IDisposable, System.Windows.Forms.IMessageFilter):  # Class
    def __init__(
        self, inputElement: System.Windows.IInputElement, seconds: int
    ) -> None: ...
    def PreFilterMessage(self, m: System.Windows.Forms.Message) -> bool: ...
    def Dispose(self) -> None: ...
    def ChangeIdleTime(self, newIdleTime: int) -> None: ...

    IsIdle: System.EventHandler  # Event

class NotifyPropertyBase(System.ComponentModel.INotifyPropertyChanged):  # Class
    def VerifyPropertyName(self, propertyName: str) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class RelayCommand(System.Windows.Input.ICommand):  # Class
    @overload
    def __init__(self, execute: System.Action) -> None: ...
    @overload
    def __init__(
        self, execute: System.Action, canExecute: System.Func[Any, bool]
    ) -> None: ...
    def CanExecute(self, parameter: Any) -> bool: ...
    def Execute(self, parameter: Any) -> None: ...
    def NotifyCanExecuteChanged(self) -> None: ...

    CanExecuteChanged: System.EventHandler  # Event

class StringNumberComparer(
    System.Collections.Generic.IComparer[str], System.Collections.IComparer
):  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def _Compare(x: str, y: str) -> int: ...
    @overload
    def Compare(self, x: str, y: str) -> int: ...
    @overload
    def Compare(self, x: Any, y: Any) -> int: ...

class Utilities:  # Class
    CustomerHome: str  # static # readonly

    @staticmethod
    def WriteRowToCsv(
        row: System.Windows.Forms.DataGridViewRow,
        writer: System.IO.TextWriter,
        delimiter: str,
    ) -> None: ...
    @staticmethod
    def GetFolder(folder: str) -> str: ...
    @staticmethod
    def ToSignificantDigits(value_: float, significantDigits: int) -> str: ...
    @staticmethod
    def GetAssemblyAttribute(assembly: System.Reflection.Assembly) -> T: ...
    @staticmethod
    def ParseTokens(
        line: str, delimiter: str
    ) -> System.Collections.Generic.List[str]: ...
    @staticmethod
    def WriteColumnHeadersToCsv(
        grid: System.Windows.Forms.DataGridView,
        writer: System.IO.TextWriter,
        delimiter: str,
    ) -> None: ...
    @staticmethod
    def WriteCsv(
        grid: System.Windows.Forms.DataGridView,
        writer: System.IO.TextWriter,
        delimiter: str,
    ) -> None: ...
    @staticmethod
    def GetDirectoryName(path: str) -> str: ...
    @staticmethod
    def EnumArrayToString(values: List[T], separator: str) -> str: ...
    @staticmethod
    def FindKnownExceptions(
        ex: System.Exception, knownTypes: List[System.Type]
    ) -> List[System.Exception]: ...
    @staticmethod
    def WriteCsvToken(
        token: str, delimiter: str, writer: System.IO.TextWriter
    ) -> None: ...
    @staticmethod
    def CultureIsKindOf(
        ci: System.Globalization.CultureInfo, cultureName: str
    ) -> bool: ...
    @staticmethod
    def StringToEnumArray(value_: str, separator: str) -> List[T]: ...
    @staticmethod
    def CopyFolder(source: str, destination: str) -> None: ...
    @staticmethod
    def GetCsvEncoding(
        ci: System.Globalization.CultureInfo,
    ) -> System.Text.Encoding: ...
    @staticmethod
    def GetHelpFilePath(basePath: str, fileName: str) -> str: ...
    @overload
    @staticmethod
    def ShowMessage(
        parent: System.Windows.Forms.IWin32Window,
        message: str,
        title: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
    ) -> System.Windows.Forms.DialogResult: ...
    @overload
    @staticmethod
    def ShowMessage(
        parent: System.Windows.Forms.IWin32Window,
        message: str,
        title: str,
        buttons: System.Windows.Forms.MessageBoxButtons,
        icon: System.Windows.Forms.MessageBoxIcon,
        helpFilePath: str,
        helpId: int,
    ) -> System.Windows.Forms.DialogResult: ...
    @staticmethod
    def CreatePen(
        color: System.Drawing.Color,
        dashStyle: System.Drawing.Drawing2D.DashStyle,
        weight: float,
    ) -> System.Drawing.Pen: ...

class WaitCursor(System.IDisposable):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, ctrl: System.Windows.Forms.Control) -> None: ...
    def Dispose(self) -> None: ...

class WaitCursorWPF(System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def Dispose(self) -> None: ...

class Win32Window(System.Windows.Forms.IWin32Window):  # Class
    @overload
    def __init__(self, window: System.Windows.Window) -> None: ...
    @overload
    def __init__(self, handle: System.IntPtr) -> None: ...

    Handle: System.IntPtr  # readonly

    @staticmethod
    def GetParentHandle(parent: System.Windows.Forms.IWin32Window) -> System.IntPtr: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Util

class ApplicationInfo:  # Class
    def __init__(self) -> None: ...

    AppDataFolder: str  # static

class Ascii:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def FromString(s: str, arrayLength: int) -> List[int]: ...
    @staticmethod
    def ToString(aBuff: List[int], iOffSet: int, iLengthToRead: int) -> str: ...

class EditablePersistantDocument:  # Class
    def __init__(
        self,
        defaultStorageFolder: str,
        DocumentName: str,
        FileExtension: str,
        fileType: str,
        documentType: str,
    ) -> None: ...

    FilePath: str  # readonly

    @overload
    def SaveEditing(self) -> bool: ...
    @overload
    def SaveEditing(
        self, confirmingFirst: bool
    ) -> Util.EditablePersistantDocument.SaveStatus: ...
    def MarkAsEdited(self) -> None: ...
    def SaveAs(self) -> None: ...
    @overload
    def LoadDocument(self) -> bool: ...
    @overload
    def LoadDocument(self, filePath: str) -> None: ...
    def Save(self) -> None: ...

    # Nested Types

    class SaveStatus(
        System.IConvertible, System.IComparable, System.IFormattable
    ):  # Struct
        NoAbort: Util.EditablePersistantDocument.SaveStatus = ...  # static # readonly
        NoContinue: Util.EditablePersistantDocument.SaveStatus = (
            ...
        )  # static # readonly
        Yes: Util.EditablePersistantDocument.SaveStatus = ...  # static # readonly

class IProgressable(object):  # Interface
    StepCount: int  # readonly

    def StepIt(self, stepIndex: int) -> bool: ...

class ListPacker:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def Unpack(code: List[int], bitSize: int) -> List[int]: ...
    @staticmethod
    def Pack(list: List[int], bitSize: int) -> List[int]: ...

class StringUtilities:  # Class
    def __init__(self) -> None: ...
    @staticmethod
    def ExtractFileName(fullFilePath: str) -> str: ...
    @staticmethod
    def FindMatchingGeneralParenthesis(data: str, parenthesis1Pos: int) -> int: ...
    @staticmethod
    def ExtractFolder(fullFilePath: str) -> str: ...
    @staticmethod
    def FormatLargeNumber(i: int) -> str: ...
    @staticmethod
    def TrimGeneralParentheses(input: str) -> str: ...
    @staticmethod
    def ExtractExtensionlessFileName(fullPath: str) -> str: ...
    @staticmethod
    def TrimLeadingInteger(input: str) -> str: ...
    @staticmethod
    def TrimTrailingInteger(input: str) -> str: ...
    @staticmethod
    def ExtractFileExtension(fileName: str) -> str: ...
    @staticmethod
    def ReplaceHtmlCharacters(text: str) -> str: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Controls

# Stubs for namespace: Agilent.MassHunter.UnknownsAnalysis.UI

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.CommandLine
):  # Class
    def __init__(self) -> None: ...

class MainWindow(
    System.Windows.Markup.IAddChild,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Media.Composition.DUCE.IResource,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IMainWindow,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.IWindowService,
    System.Windows.Forms.IWin32Window,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command.CommandContext,
    ) -> None: ...

    ActivePane: str  # readonly
    AddInManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.AddInManager
    )  # readonly
    AnalysisMessageTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IAnalysisMessageTableControl
    )  # readonly
    ChromatogramControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IChromatogramControl
    )  # readonly
    ComponentTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IComponentTableControl
    )  # readonly
    EicPeaksControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IEicPeaksControl
    )  # readonly
    ExactMassTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IExactMassTableControl
    )  # readonly
    Handle: System.IntPtr  # readonly
    InvokeRequired: bool  # readonly
    IonPeaksControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IIonPeaksControl
    )  # readonly
    IsDisposed: bool  # readonly
    IsHandleCreated: bool  # readonly
    SampleTableControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISampleTableControl
    )  # readonly
    ScriptControl: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils.ScriptControl
    )  # readonly
    SpectrumControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.ISpectrumControl
    )  # readonly
    StructureControl: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IStructureControl
    )  # readonly
    ToolManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager
    )  # readonly
    UIContext: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.Model.IUIContext
    )  # readonly
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState
    )  # readonly
    _UIState: Agilent.MassHunter.UnknownsAnalysis.UI.UIState  # readonly

    def Layout4(self) -> None: ...
    def ActivateWindow(self) -> None: ...
    def Layout6(self) -> None: ...
    def DefaultLayout(self) -> None: ...
    def Layout1(self) -> None: ...
    def Layout3(self) -> None: ...
    def Layout2(self) -> None: ...
    def Layout7(self) -> None: ...
    def SetLayout(self, layout: int) -> None: ...
    def SetPaneVisible(self, key: str, visible: bool) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def InitializeComponent(self) -> None: ...
    def Close(self, forceClose: bool) -> None: ...
    def IsPaneVisible(self, key: str) -> bool: ...
    def BeginInvoke(self, d: System.Delegate, parameters: List[Any]) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def ShowQuery(self, queryFile: str) -> None: ...
    def Invoke(self, d: System.Delegate, parameters: List[Any]) -> Any: ...
    def Layout5(self) -> None: ...

    PaneVisibleChanged: System.EventHandler  # Event

class ToolHandlerApplicationMenu(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objState: Any,
    ) -> None: ...

class ToolHandlerUnknownsWPF(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objState: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        objState: Any,
    ) -> None: ...

class ToolIds:  # Class
    App_File_NewAnalysis: str = ...  # static # readonly
    App_File_OpenAnalysis: str = ...  # static # readonly
    App_File_SaveAnalysisAs: str = ...  # static # readonly
    UnknownsWPF_Analyze_All: str = ...  # static # readonly
    UnknownsWPF_Analyze_AllSamples: str = ...  # static # readonly
    UnknownsWPF_Analyze_Sample: str = ...  # static # readonly
    UnknownsWPF_ComponentsHits: str = ...  # static # readonly
    UnknownsWPF_Import: str = ...  # static # readonly
    UnknownsWPF_Method_Load: str = ...  # static # readonly
    UnknownsWPF_Samples: str = ...  # static # readonly

class ToolManager(
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.IToolManager,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    Agilent.MassHunter.Quantitative.ToolbarWPF.ToolManager.ToolManagerBase,
):  # Class
    def __init__(
        self,
        ribbon: Infragistics.Windows.Ribbon.XamRibbon,
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
    ) -> None: ...

    IUIState: (
        Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState
    )  # readonly

    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def ApplicationMenu2010SelectedTabItemChanged(self) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def GetApplicationMenu2010Content(self, category: str, id: str) -> Any: ...
    def GetToolTooltip(self, id: str) -> str: ...
    @staticmethod
    def _GetImage(image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def ApplicationMenu2010Closed(self) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    @staticmethod
    def DelegateExecute(
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        ID: str,
    ) -> None: ...
    @staticmethod
    def DelegateSetToolState(
        uiState: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
        tool: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        ID: str,
    ) -> None: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...

class UIState(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIFImpls.UIState,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF.IUIState,
):  # Class
    def __init__(
        self, mainWindow: Agilent.MassHunter.UnknownsAnalysis.UI.MainWindow
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Configuration

class ColumnWidthItem:  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, column: str, width: float) -> None: ...

    Column: str
    Width: float

class ColumnWidths:  # Class
    def __init__(self) -> None: ...
    def __getitem__(self, name: str) -> Optional[float]: ...
    def __setitem__(self, name: str, value_: Optional[float]) -> None: ...
    Widths: List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Configuration.ColumnWidthItem
    ]

class Configuration:  # Class
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Configuration.Configuration
    )  # static # readonly
    UserSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Configuration.UserSettings
    )  # readonly

    @staticmethod
    def Cleanup() -> None: ...

class UserSettings(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.ConfigurationElementSectionBase
):  # Class
    def __init__(self) -> None: ...

    FileListColumnWidths: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.ECMHelper.Configuration.ColumnWidths
    )
    LastFileDialogSize: Optional[System.Windows.Size]
    LastFolder: str



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.ReportBuilder.Renderer.Text

class Renderer(
    System.IDisposable, Agilent.MassHunter.ReportBuilder.Engine.IReportRenderer
):  # Class
    def __init__(self, writer: System.IO.TextWriter, delimiter: str) -> None: ...

    Context: Agilent.MassHunter.ReportBuilder.Engine.IReportContext

    def RenderImage(
        self, image: Agilent.MassHunter.ReportBuilder.Template.IImage
    ) -> None: ...
    def StartDocument(self) -> None: ...
    def PageBreak(self) -> None: ...
    def RenderTable(
        self, numColumns: int
    ) -> Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer: ...
    def RenderGraphics(
        self, graphics: Agilent.MassHunter.ReportBuilder.Template.IGraphics
    ) -> None: ...
    def RenderText(
        self, textbox: Agilent.MassHunter.ReportBuilder.Template.ITextbox
    ) -> None: ...
    def EndDocument(self) -> None: ...
    def SetPage(
        self, page: Agilent.MassHunter.ReportBuilder.Template.IPage
    ) -> None: ...
    def Dispose(self) -> None: ...

class TableRenderer(Agilent.MassHunter.ReportBuilder.Engine.ITableRenderer):  # Class
    def SetColumnWidths(self, widths: List[float]) -> None: ...
    def EndTable(self) -> None: ...
    def SetProperties(
        self, table: Agilent.MassHunter.ReportBuilder.Template.ITable
    ) -> None: ...
    def StartHeader(self) -> None: ...
    def EndHeader(self) -> None: ...
    def AddCell(
        self, cell: Agilent.MassHunter.ReportBuilder.Template.ITableCell
    ) -> None: ...
    def EndRow(self) -> None: ...



# -*- coding: utf-8 -*-
from __future__ import (
    absolute_import,
    division,
    generators,
    nested_scopes,
    print_function,
    unicode_literals,
    with_statement,
)

import os
import sys

from mh_operator.legacy.common import global_state, logger

try:
    import clr

    clr.AddReference("CoreCommand")
    clr.AddReference("MethodSetup")
    clr.AddReference("UnknownsAnalysisII")
    clr.AddReference("UnknownsAnalysisII.Command")
    clr.AddReference("UnknownsAnalysisII.UI")

    import _commands
    import System
    from Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command import (
        AddTargetCompoundParameter,
        KeyValue,
        TargetCompoundColumnValuesParameter,
    )

    uadacc = global_state.UADataAccess
except ImportError:
    assert sys.executable is not None, "Should never reach here"
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII import (
        Command as _commands,
    )
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.Command import (
        AddTargetCompoundParameter,
        KeyValue,
        TargetCompoundColumnValuesParameter,
    )
    from mh_operator.SDK.Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.UI.ScriptIF import (
        IUADataAccess,
    )

    uadacc = IUADataAccess()

from mh_operator.legacy import UnknownsAnalysisDataSet
from mh_operator.legacy.UnknownsAnalysisDataSet import DataTables, TargetCompoundRow


class Sample(object):
    def __init__(self, path, type="Sample"):
        self.path = os.path.realpath(path)
        self.type = type

    @property
    def folder(self):
        return os.path.split(self.path)[0]

    @property
    def name(self):
        return os.path.split(self.path)[1]

    def __str__(self):
        return "< {} : {} >".format(self.name, self.type)


class ISTD(object):
    def __init__(
        self,
        istd_rt=None,
        rt_delta=(0.5, 0.5),
        istd_value=None,
        istd_name=None,
        istd_cas=None,
        istd_index=None,
        recover_rt=None,
        recover_name=None,
        recover_value=None,
        from_sample=None,
    ):
        self.istd_rt = istd_rt
        self.l_rt_delta, self.r_rt_delta = (
            (rt_delta, rt_delta) if isinstance(rt_delta, (int, float)) else rt_delta
        )
        self.istd_value = istd_value
        self.istd_name = istd_name
        self.istd_cas = istd_cas
        self.istd_index = istd_index
        self.recover_rt = recover_rt
        self.recover_name = recover_name
        self.recover_value = recover_value

        assert self.istd_value is not None or (
            self.recover_value is not None and self.recover_rt is not None
        ), "recovery compound must be set when ISTD value not set"

        self.from_sample = from_sample

    def to_dict(self):
        # type: () -> dict
        return dict(
            ISTDFlag=True,
            MZ=0.0,
            RetentionTime=self.istd_rt,
            LeftRetentionTimeDelta=self.l_rt_delta,
            RightRetentionTimeDelta=self.r_rt_delta,
            RetentionTimeDeltaUnits="Minutes",
            CompoundName=self.istd_name,
            CASNumber=self.istd_cas,
            ISTDConcentration=self.istd_value,
        )

    def find_istd_compound(self, tables, sample_id=None):
        # type: (dict, int) -> dict
        def find_component(rt, l_rt, r_rt, name, s_id):
            rt_diffs = (
                (abs(_rt - rt), r)
                for r, (_rt, _name, _id) in enumerate(
                    zip(
                        tables["RetentionTime"],
                        tables["CompoundName"],
                        tables["SampleID"],
                    )
                )
                if _rt > l_rt
                and _rt < r_rt
                and (name is None or _name == name)
                and (id is None or _id == s_id)
            )
            try:
                _, row = min(rt_diffs)
                return row
            except ValueError:
                logger.warn(
                    "no compound candidate found in R.T. ({}-{}, {}+{}) with name {}".format(
                        rt, rt - l_rt, rt, r_rt - rt, name
                    )
                )
                return None

        row = find_component(
            self.istd_rt,
            self.istd_rt - self.l_rt_delta,
            self.istd_rt + self.r_rt_delta,
            self.istd_name,
            sample_id,
        )
        assert row is not None, "Did not find the ISTD compound"

        target = {
            k: tables[k][row]
            for k in ("CompoundName", "CASNumber", "RetentionTime", "RetentionIndex")
        }

        if self.recover_value is not None:
            recover_row = find_component(
                self.recover_rt,
                self.recover_rt - self.l_rt_delta,
                self.recover_rt + self.r_rt_delta,
                self.recover_name,
                sample_id,
            )
            assert (
                recover_row is not None
            ), "Did not find the recover compound for ISTD value setting"

            target["ISTDConcentration"] = (
                tables["Area"][row] * self.recover_value / tables["Area"][recover_row]
            )

        logger.info("ISTD compound info to be updated: {}".format(target))
        return target

    @staticmethod
    def target_operations(sample_ids, column_values, target_id=0, batch_id=0):
        # type: (list, dict, int, int) -> list
        kv = [
            KeyValue(k, v)
            for k, v in column_values.items()
            if v is not None and k != "SampleID"
        ]
        return [
            AddTargetCompoundParameter(batch_id, s, target_id) for s in sample_ids
        ] + [
            TargetCompoundColumnValuesParameter(batch_id, s, target_id, kv)
            for s in sample_ids
        ]


def export_analysis(analysis_file=None):
    if analysis_file is not None:
        folder, name = os.path.split(analysis_file)
        _commands.OpenAnalysis(os.path.join(folder, ".."), name, True)
    try:
        tables = DataTables()

        tables.Analysis = [uadacc.GetAnalysis()]
        tables.Batch = [uadacc.GetBatches()]
        (batch_id,) = tables.Batch["BatchID"]
        tables.Sample = [uadacc.GetSamples(batch_id)]
        sample_ids = tables.Sample["SampleID"]

        tables.Component = (uadacc.GetComponents(batch_id, s) for s in sample_ids)
        tables.Hit = (uadacc.GetHits(batch_id, s) for s in sample_ids)
        tables.IonPeak = (uadacc.GetIonPeak(batch_id, s) for s in sample_ids)
        tables.DeconvolutionMethod = (
            uadacc.GetDeconvolutionMethods(batch_id, s) for s in sample_ids
        )
        tables.LibrarySearchMethod = (
            uadacc.GetLibrarySearchMethods(batch_id, s) for s in sample_ids
        )
        tables.IdentificationMethod = (
            uadacc.GetIdentificationMethods(batch_id, s) for s in sample_ids
        )
        tables.TargetCompound = (
            uadacc.GetTargetCompounds(batch_id, s) for s in sample_ids
        )
        tables.Peak = (uadacc.GetPeak(batch_id, s) for s in sample_ids)
        tables.TargetQualifier = (
            uadacc.GetTargetQualifier(batch_id, s) for s in sample_ids
        )
        tables.PeakQualifier = (
            uadacc.GetPeakQualifier(batch_id, s) for s in sample_ids
        )
        tables.TargetMatchMethod = (
            uadacc.GetTargetMatchMethods(batch_id, s) for s in sample_ids
        )
        tables.AuxiliaryMethod = (
            uadacc.GetAuxiliaryMethod(batch_id, s) for s in sample_ids
        )

        return tables
    finally:
        if analysis_file is not None:
            _commands.CloseAnalysis()


def analysis_samples(
    analysis_name, samples, analysis_method, istd=None, report_method=None
):
    # type: (str, list, str, ISTD, str) -> dict
    (batch_folder,) = set(os.path.split(s.path)[0] for s in samples)
    analysis_file = os.path.join(batch_folder, "UnknownsResults", analysis_name)

    if os.path.exists(analysis_file):
        logger.info("Cleaning existing analysis {}".format(analysis_file))
        os.unlink(analysis_file)

    _commands.NewAnalysis(batch_folder, analysis_name)
    logger.info(
        "Analysis project {} created under {}".format(analysis_name, batch_folder)
    )

    _commands.AddSamples(System.Array[System.String]([s.path for s in samples]))
    batch_id = next(iter(uadacc.GetBatches())).BatchID
    samples_id = {s.DataFileName: s.SampleID for s in uadacc.GetSamples(batch_id)}
    logger.info("Added samples {}".format(samples_id))

    for s in samples:
        if s.type is not None:
            _commands.SetSample(batch_id, samples_id[s.name], "SampleType", s.type)
    logger.info("Samples Type updated")

    _commands.LoadMethodToAllSamples(analysis_method)
    logger.info("Method {} loaded to all samples".format(analysis_method))

    if istd is not None:
        target_compound = istd.to_dict()

        if istd.from_sample is not None:
            istd_sample_id = samples_id.get(os.path.basename(istd.from_sample), None)
            assert istd_sample_id is not None, "ISTD sample not correctly set"

            logger.info(
                "Analysis one sample ({}) with id {} to setup ISTD".format(
                    istd.from_sample, istd_sample_id
                )
            )
            _commands.AnalyzeSamples(batch_id, istd_sample_id, True)

            tables_data = DataTables()
            tables_data.Component = [uadacc.GetComponents(batch_id, istd_sample_id)]
            tables_data.Hit = [uadacc.GetHits(batch_id, istd_sample_id)]
            istd_sample_components = tables_data.ComponentsWithBestPrimaryHit(
                batch_id, istd_sample_id
            )
            target_compound.update(
                **istd.find_istd_compound(
                    istd_sample_components, sample_id=istd_sample_id
                )
            )

        logger.info("Apply ISTD target compound info: {}".format(target_compound))
        assert all(
            target_compound.get(k, None) is not None
            for k in (
                "ISTDFlag",
                "MZ",
                "RetentionTime",
                "LeftRetentionTimeDelta",
                "RightRetentionTimeDelta",
                "RetentionTimeDeltaUnits",
                "CompoundName",
                "ISTDConcentration",
            )
        ), "Must set valid values for the ISTD table"
        _commands.SetTargets(
            istd.target_operations(
                samples_id.values(),
                target_compound,
                target_id=0,
                batch_id=batch_id,
            )
        )

    _commands.AnalyzeAll(True)
    _commands.SaveAnalysis()

    with open(analysis_file + ".json", "w") as fp:
        fp.write(export_analysis().to_json())
        logger.info("Analysis results exported into {}".format(fp.name))

    _commands.CloseAnalysis()
    logger.info("Analysis Closed")

    if report_method is not None:
        import subprocess

        from mh_operator.legacy.common import __DEFAULT_MH_BIN_DIR__

        report_path = os.path.join(batch_folder, "UnknownsReports", analysis_name)
        subprocess.call(
            [
                os.path.join(
                    os.environ.get("MH_BIN_DIR", __DEFAULT_MH_BIN_DIR__),
                    "UnknownsAnalysisII.ReportResults.exe",
                ),
                "-BP={}".format(batch_folder),
                "-AF={}".format(analysis_name),
                "-M={}".format(os.path.realpath(report_method)),
                "-OP={}".format(report_path),
            ]
        )
        logger.info(
            "Report generated under {} with method {}".format(
                report_path, report_method
            )
        )



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import Exceptions, Math, Utilities

# Discovered Generic TypeVars:
T = TypeVar("T")

# Stubs for namespace: Agilent.OpenLab.Framework.DataAccess.CoreTypes

class ApprovalLevelType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IApprovalLevelType
):  # Class
    def __init__(self) -> None: ...

    Comment: str
    EntryBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    EntryDate: System.DateTime
    LevelName: str
    LevelNo: int
    Reason: str

class ApprovalsType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IApprovalsType
):  # Class
    def __init__(self) -> None: ...

    Levels: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ApprovalLevelType
    ]

class AuditTrailEntryType:  # Class
    def __init__(self) -> None: ...

    Date: System.DateTime
    Description: str
    EntryBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    Reason: str
    UserText: Any

class Axis(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    X: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Axis = ...  # static # readonly
    Y: Agilent.OpenLab.Framework.DataAccess.CoreTypes.Axis = ...  # static # readonly

class BackgroundSourceType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    DesignatedBackgroundSpectrum: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType
    ) = ...  # static # readonly
    DesignatedTimeRange: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType
    ) = ...  # static # readonly
    MissingSpectra: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType
    ) = ...  # static # readonly
    PeakEnd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType = (
        ...
    )  # static # readonly
    PeakStart: Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType = (
        ...
    )  # static # readonly
    PeakStartAndEnd: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType
    ) = ...  # static # readonly

class BaseExtractionParameters(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters
):  # Class
    LongDisplayString: str  # readonly
    ShortDisplayString: str  # readonly

    @overload
    def ShiftTimeValues(self, delta: float) -> None: ...
    @overload
    def ShiftTimeValues(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    def Serialize(self) -> str: ...

class CalibrationCurveCoeffType:  # Class
    def __init__(self) -> None: ...

    A: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    B: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    C: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    D: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    E: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    F: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType

class CalibrationCurveOriginEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Connect: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum
    ) = ...  # static # readonly
    Force: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum = (
        ...
    )  # static # readonly
    Include: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum
    ) = ...  # static # readonly
    Undefined: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum
    ) = ...  # static # readonly

class CalibrationCurveType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationCurveType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
):  # Class
    def __init__(self) -> None: ...

    AreRelativeValues: bool
    AreRelativeValuesSpecified: bool
    CalibrationLevels: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationLevelType
    ]
    Coefficients: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveCoeffType
    )
    CorrCoefficient: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    DetermCoefficient: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Formula: str
    Info: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectInfoType
    Origin: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorCalcMode: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ResponseFactorCalcModeEnum
    )
    ResponseFactorCalcModeSpecified: bool
    ResponseFactorRSDPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Scale: str
    Type: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    TypeDescription: str
    WeightType: str

class CalibrationCurveTypeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AverageRF: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly
    Cubic: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum = (
        ...
    )  # static # readonly
    Custom: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum = (
        ...
    )  # static # readonly
    Exponential: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly
    Linear: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum = (
        ...
    )  # static # readonly
    LogLog: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum = (
        ...
    )  # static # readonly
    Logarithmic: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly
    Piecewise: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly
    Power: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum = (
        ...
    )  # static # readonly
    Quadratic: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly
    Undefined: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    ) = ...  # static # readonly

class CalibrationHistoryType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationHistoryType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    def __init__(self) -> None: ...

    Amount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AmountAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    DataFileName: str
    ProcessedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    ProcessedDate: System.DateTime
    ProcessedDateSpecified: bool
    RelativeResidual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    RelativeResidualPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Response: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    SampleName: str
    Valid: bool
    ValidSpecified: bool

class CalibrationLevelType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICalibrationLevelType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    def __init__(self) -> None: ...

    Amount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageAmountAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageResponse: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageResponseAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    CalibrationHistories: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationHistoryType
    ]
    Level: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    RelativeResidual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    RelativeResidualPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactor: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorRelStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Valid: bool
    ValidSpecified: bool

class ChromAcquisitionDetails(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromAcquisitionDetails
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, isIntRawData: bool) -> None: ...

    IsIntRawData: bool  # readonly

class ChromData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISubtractableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
):  # Class
    def __init__(
        self,
        data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
        xunit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit,
        yunit: str,
    ) -> None: ...

    ChromAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromAcquisitionDetails
    )
    Data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData  # readonly
    MsAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )
    SignalDescription: str
    SignalName: str
    XUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit  # readonly
    YUnit: str  # readonly

    def ConvertDataToCompatibleUnit(
        self, data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...
    @overload
    def Shift(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    @overload
    def Shift(self, delta: float) -> None: ...
    def Subtract(
        self, dataToSubtract: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ) -> None: ...
    def Clone(self) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData: ...

class ChromDataEx(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISubtractableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromDataEx,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromDataEx
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData,
):  # Class
    @overload
    def __init__(
        self,
        data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
        xUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit,
        yUnit: str,
    ) -> None: ...
    @overload
    def __init__(
        self,
        data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
        xUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit,
        yUnit: str,
        originalName: str,
        dataSlope: Optional[float],
        dataIntercept: Optional[float],
    ) -> None: ...
    @overload
    def __init__(
        self,
        data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
        xUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit,
        yUnit: str,
        originalName: str,
        dataSlope: Optional[float],
        dataIntercept: Optional[float],
        yAxisScalingFactor: Optional[float],
    ) -> None: ...

    DataIntercept: Optional[float]  # readonly
    DataSlope: Optional[float]  # readonly
    OrginalName: str  # readonly
    YScalingFactor: Optional[float]  # readonly

class ChromatogramExtractionParameters(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.BaseExtractionParameters,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        extractionType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType,
    ) -> None: ...
    @overload
    def __init__(
        self,
        extractionType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType,
        extractionTimeRange: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeRange,
        extractionTimeRangeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    @overload
    def __init__(
        self, neutralMass: float, intervalLow: float, intervalHigh: float
    ) -> None: ...
    @overload
    def __init__(
        self,
        neutralMass: float,
        intervalLow: float,
        intervalHigh: float,
        extractionTimeRange: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeRange,
        extractionTimeRangeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...

    ExtractionTimeRange: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeRange
    ExtractionTimeRangeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit
    ExtractionType: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType
    )
    IntervalHigh: float
    IntervalLow: float
    LongDisplayString: str  # readonly
    MsExtractionParameters: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsExtractionParameters
    )
    NeutralMass: float
    ShortDisplayString: str  # readonly

    def Serialize(self) -> str: ...

class ChromatogramExtractionType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    BPC: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType = (
        ...
    )  # static # readonly
    EIC: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType = (
        ...
    )  # static # readonly
    SIM: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType = (
        ...
    )  # static # readonly
    TIC: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionType = (
        ...
    )  # static # readonly

class Data(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ],
):  # Class
    def __init__(self, xValues: List[float], yValues: List[float]) -> None: ...

    XValues: List[float]  # readonly
    YValues: List[float]  # readonly

    def Shift(self, delta: float) -> None: ...
    def Subtract(
        self, dataToSubtract: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ) -> None: ...
    def Clone(self) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData: ...

class DetectorType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Adc: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Afc: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Ce: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Dad: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Dfpd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Ecd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Elsd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Fid: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Fld: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Fpd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Mecd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Ms: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Msms: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Mwd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Npd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Rid: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Tcd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Tst: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Unknown: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Uv: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly
    Vwd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType = (
        ...
    )  # static # readonly

class DoubleType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ValueBaseType,
):  # Class
    def __init__(self) -> None: ...

    Val: float

class DoubleTypeExtensions:  # Class
    @overload
    @staticmethod
    def Equals(
        double1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        double2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    ) -> bool: ...
    @overload
    @staticmethod
    def Equals(
        double1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        double2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        comparisonMode: Agilent.OpenLab.Framework.DataAccess.CoreTypes.NumericComparison,
        precision: float,
    ) -> bool: ...
    @overload
    @staticmethod
    def GetValue(
        baseType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    ) -> float: ...
    @overload
    @staticmethod
    def GetValue(
        baseType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        defaultValue: float,
    ) -> float: ...
    @overload
    @staticmethod
    def TryGetValue(
        baseType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    ) -> Optional[float]: ...
    @overload
    @staticmethod
    def TryGetValue(
        baseType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        defaultValue: float,
    ) -> float: ...
    @overload
    @staticmethod
    def DoubleTypeEquals(
        double1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        double2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    ) -> bool: ...
    @overload
    @staticmethod
    def DoubleTypeEquals(
        double1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        double2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
        comparisonMode: Agilent.OpenLab.Framework.DataAccess.CoreTypes.NumericComparison,
        precision: float,
    ) -> bool: ...
    @staticmethod
    def DoubleTypeToString(
        doubleType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IDoubleType,
    ) -> str: ...

class EqualizeMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Combined: Agilent.OpenLab.Framework.DataAccess.CoreTypes.EqualizeMode = (
        ...
    )  # static # readonly
    First: Agilent.OpenLab.Framework.DataAccess.CoreTypes.EqualizeMode = (
        ...
    )  # static # readonly
    Overlap: Agilent.OpenLab.Framework.DataAccess.CoreTypes.EqualizeMode = (
        ...
    )  # static # readonly
    Second: Agilent.OpenLab.Framework.DataAccess.CoreTypes.EqualizeMode = (
        ...
    )  # static # readonly

class EquidistantData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IEquidistantData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IEquidistantData
    ],
):  # Class
    def __init__(self, yValues: List[float], xMin: float, xStep: float) -> None: ...

    XMin: float  # readonly
    XStep: float  # readonly
    YValues: List[float]  # readonly

    def Shift(self, delta: float) -> None: ...
    def Subtract(
        self, dataToSubtract: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ) -> None: ...

class GenericAnalyticalResultDataInfo(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IGenericAnalyticalResultDataInfo
):  # Class
    def __init__(self) -> None: ...

    DataChannelDescription: str
    DataChannelId: str
    DataChannelName: str
    DataContentId: str
    DataContentSequenceNumber: str
    DataContentType: str
    RawDataFilePath: str
    TraceId: str

class IApprovalLevelType(object):  # Interface
    Comment: str
    EntryBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    EntryDate: System.DateTime
    LevelName: str
    LevelNo: int
    Reason: str

class IApprovalsType(object):  # Interface
    Levels: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ApprovalLevelType
    ]

class ICalibrationCurveType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Interface
    AreRelativeValues: bool
    AreRelativeValuesSpecified: bool
    CalibrationLevels: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationLevelType
    ]
    Coefficients: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveCoeffType
    )
    CorrCoefficient: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    DetermCoefficient: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Formula: str
    Info: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectInfoType
    Origin: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveOriginEnum
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorCalcMode: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ResponseFactorCalcModeEnum
    )
    ResponseFactorCalcModeSpecified: bool
    ResponseFactorRSDPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Scale: str
    Type: Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationCurveTypeEnum
    TypeDescription: str
    WeightType: str

class ICalibrationHistoryType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot
):  # Interface
    Amount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AmountAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    DataFileName: str
    ProcessedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    ProcessedDate: System.DateTime
    ProcessedDateSpecified: bool
    RelativeResidual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    RelativeResidualPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Response: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    SampleName: str
    Valid: bool
    ValidSpecified: bool

class ICalibrationLevelType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot
):  # Interface
    Amount: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageAmountAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageResponse: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    AverageResponseAbs: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    CalibrationHistories: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.CalibrationHistoryType
    ]
    Level: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IntegerType
    RelativeResidual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    RelativeResidualPercent: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Residual: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactor: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorRelStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    ResponseFactorStdDev: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DoubleType
    Valid: bool
    ValidSpecified: bool

class IChromAcquisitionDetails(object):  # Interface
    IsIntRawData: bool  # readonly

class IChromData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISubtractableData,
):  # Interface
    ChromAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromAcquisitionDetails
    )  # readonly
    Data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData  # readonly
    MsAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )  # readonly
    SignalDescription: str
    SignalName: str
    XUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit  # readonly
    YUnit: str  # readonly

class IChromDataEx(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISubtractableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromDataEx
    ],
):  # Interface
    DataIntercept: Optional[float]  # readonly
    DataSlope: Optional[float]  # readonly
    OrginalName: str  # readonly
    YScalingFactor: Optional[float]  # readonly

class ICloneableData(object):  # Interface
    def Clone(self) -> T: ...

class IData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ]
):  # Interface
    XValues: List[float]  # readonly
    YValues: List[float]  # readonly

    def Shift(self, delta: float) -> None: ...
    def Subtract(
        self, dataToSubtract: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ) -> None: ...

class IDoubleType(object):  # Interface
    Val: float

class IEquidistantData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IEquidistantData
    ],
):  # Interface
    XMin: float  # readonly
    XStep: float  # readonly

class IExtractionParameters(object):  # Interface
    LongDisplayString: str  # readonly
    ShortDisplayString: str  # readonly

    @overload
    def ShiftTimeValues(self, delta: float) -> None: ...
    @overload
    def ShiftTimeValues(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    def Serialize(self) -> str: ...

class IGenericAnalyticalResultDataInfo(object):  # Interface
    DataChannelDescription: str  # readonly
    DataChannelId: str  # readonly
    DataChannelName: str  # readonly
    DataContentId: str  # readonly
    DataContentSequenceNumber: str  # readonly
    DataContentType: str  # readonly
    RawDataFilePath: str  # readonly
    TraceId: str  # readonly

class IIntegerType(object):  # Interface
    Val: int

class IMethodConfigurationType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Interface
    MethodDescription: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodSectionType
    Ver: int

class IMethodItemBaseType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot
):  # Interface
    ID: str
    Name: str

class IMethodParameterType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Interface
    Unit: str
    Value: str

class IMethodRowType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot
):  # Interface
    Parameters: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodParameterType
    ]

class IMethodSectionType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Interface
    Parameters: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodParameterType
    ]
    Sections: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodSectionType
    ]
    Tables: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodTableType
    ]

class IMethodTableType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Interface
    Rows: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodRowType
    ]

class IMsAcquisitionDetails(object):  # Interface
    CollisionEnergy: float  # readonly
    FragmentorIsDynamic: bool  # readonly
    FragmentorVoltage: float  # readonly
    IonPolarity: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity  # readonly
    IonizationMode: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode
    )  # readonly
    MsLevels: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsLevel  # readonly
    MsScanType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType  # readonly

class IMsRawDataInformation(object):  # Interface
    AcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )  # readonly
    BasicSignalExtractionParams: Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionParameters
    ]  # readonly
    FragmentVoltages: List[float]  # readonly
    SIMIons: List[float]  # readonly

class IObjectBaseType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot
):  # Interface
    Id: str

    def SetNewId(self, id: System.Guid) -> None: ...
    def GetGuid(self) -> System.Guid: ...

class IObjectInfoType(object):  # Interface
    Approvals: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ApprovalsType
    AuditTrail: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.AuditTrailEntryType
    ]
    CreatedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    CreatedDate: System.DateTime
    CreatedDateSpecified: bool
    LastModifiedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    LastModifiedDate: System.DateTime
    LastModifiedDateSpecified: bool
    Status: str

class IObjectRoot(object):  # Interface
    ...

class IShiftableData(object):  # Interface
    @overload
    def Shift(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    @overload
    def Shift(self, delta: float) -> None: ...

class ISignalInformation(object):  # Interface
    MSRawDataInformation: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsRawDataInformation
    )  # readonly

class ISmooth(object):  # Interface
    Name: str  # readonly

    def Smooth(self, x: List[float], y: List[float]) -> List[float]: ...

class ISpectraData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData
    ]
):  # Interface
    Data: Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData
    ]  # readonly
    SpectraDescription: str  # readonly
    SpectraName: str  # readonly

    def CountDataPoints(self) -> int: ...
    @overload
    def GetSpectrum(
        self, time: float
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    @overload
    def GetSpectrum(
        self,
        time: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    @overload
    def GetSpectrum(
        self,
        spectrumExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    @overload
    def Shift(self, delta: float) -> None: ...
    @overload
    def Shift(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...

class ISpectrumData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
):  # Interface
    Data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData  # readonly
    Description: str
    ExprType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr
    MsAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )  # readonly
    Name: str
    Time: Optional[float]  # readonly
    TimeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit
    XUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit  # readonly
    YUnit: str  # readonly

class ISubtractableData(object):  # Interface
    def Subtract(
        self, dataToSubtract: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IChromData
    ) -> None: ...

class IntegerType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IIntegerType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ValueBaseType,
):  # Class
    def __init__(self) -> None: ...

    Val: int

class IonPolarity(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Mixed: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity = (
        ...
    )  # static # readonly
    Negative: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity = (
        ...
    )  # static # readonly
    Positive: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity = (
        ...
    )  # static # readonly
    Unassigned: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity = (
        ...
    )  # static # readonly

class IonizationMode(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apci: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    Appi: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    CI: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    EI: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    Esi: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    ICP: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    JetStream: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    Maldi: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    Mixed: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    MsChip: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    NanoEsi: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly
    Unspecified: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode = (
        ...
    )  # static # readonly

class MethodConfigurationType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodConfigurationType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
):  # Class
    def __init__(self) -> None: ...

    MethodDescription: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodSectionType
    Ver: int

class MethodParameterType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodParameterType,
):  # Class
    def __init__(self) -> None: ...

    ID: str
    Name: str
    Unit: str
    Value: str

class MethodRowType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodRowType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    def __init__(self) -> None: ...

    Parameters: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodParameterType
    ]

class MethodSectionType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodSectionType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    def __init__(self) -> None: ...

    ID: str
    Name: str
    Parameters: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodParameterType
    ]
    Sections: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodSectionType
    ]
    Tables: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodTableType
    ]

class MethodTableType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodTableType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMethodItemBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    def __init__(self) -> None: ...

    ID: str
    Name: str
    Rows: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MethodRowType
    ]

class MsAcquisitionDetails(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
):  # Class
    @overload
    def __init__(
        self,
        ionizationMode: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode,
        ionPolarity: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity,
        msScanType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType,
    ) -> None: ...
    @overload
    def __init__(self) -> None: ...

    CollisionEnergy: float
    FragmentorIsDynamic: bool
    FragmentorVoltage: float
    IonPolarity: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity
    IonizationMode: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode
    MsLevels: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsLevel
    MsScanType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType

class MsExtractionParameters:  # Class
    def __init__(self) -> None: ...

    CollisionEnergy: float
    FragmentorVoltage: float
    IonPolarity: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonPolarity
    IonizationMode: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IonizationMode
    MSScanType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType

class MsLevel(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    All: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsLevel = (
        ...
    )  # static # readonly
    MS: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsLevel = (
        ...
    )  # static # readonly
    MSMS: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsLevel = (
        ...
    )  # static # readonly

class MsRawDataInformation(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsRawDataInformation
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        acquisitionDetails: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails,
        simIons: List[float],
        basicSignalExtractionParams: Iterable[
            Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionParameters
        ],
        fragmentVoltages: List[float],
    ) -> None: ...

    AcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )  # readonly
    BasicSignalExtractionParams: Iterable[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ChromatogramExtractionParameters
    ]  # readonly
    FragmentVoltages: List[float]  # readonly
    SIMIons: List[float]

class MsScanType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    All: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    AllMS: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    AllMSN: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    HighResolutionScan: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    MultipleReaction: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    NeutralGain: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    NeutralLoss: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    PrecursorIon: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    ProductIon: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    Scan: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    SelectedIon: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    TotalIon: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly
    Unspecified: Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsScanType = (
        ...
    )  # static # readonly

class NumericComparison(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AbsolutePrecision: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.NumericComparison
    ) = ...  # static # readonly
    Exact: Agilent.OpenLab.Framework.DataAccess.CoreTypes.NumericComparison = (
        ...
    )  # static # readonly
    RelativePrecision: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.NumericComparison
    ) = ...  # static # readonly

class ObjectBaseType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectBaseType,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
):  # Class
    Id: str

    def SetNewId(self, id: System.Guid) -> None: ...
    def GetGuid(self) -> System.Guid: ...

class ObjectInfoType(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectInfoType
):  # Class
    def __init__(self) -> None: ...

    Approvals: Agilent.OpenLab.Framework.DataAccess.CoreTypes.ApprovalsType
    AuditTrail: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.AuditTrailEntryType
    ]
    CreatedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    CreatedDate: System.DateTime
    CreatedDateSpecified: bool
    LastModifiedBy: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UserLinkType
    LastModifiedDate: System.DateTime
    LastModifiedDateSpecified: bool
    Status: str

class ObjectRootExtensions:  # Class
    @staticmethod
    def CloneBySerialization(source: T, useTempFile: bool = ...) -> T: ...
    @overload
    @staticmethod
    def Compare(
        source: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        target: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        ignoreIdProperties: bool,
    ) -> bool: ...
    @overload
    @staticmethod
    def Compare(
        source: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        target: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        ignoreIdProperties: bool,
        comparisonResults: str,
    ) -> bool: ...
    @overload
    @staticmethod
    def Compare(
        source: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        target: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        ignoreIdProperties: bool,
        maxDiffCount: int,
        comparisonResults: str,
    ) -> bool: ...
    @staticmethod
    def Clone(
        sourceObj: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IObjectRoot,
        useParallelCloning: bool = ...,
        cancellationToken: System.Threading.CancellationToken = ...,
    ) -> Any: ...

class ResponseFactorCalcModeEnum(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    AmountPerResponse: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ResponseFactorCalcModeEnum
    ) = ...  # static # readonly
    ResponsePerAmount: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ResponseFactorCalcModeEnum
    ) = ...  # static # readonly
    Undefined: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ResponseFactorCalcModeEnum
    ) = ...  # static # readonly

class SeparationTechnology(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CapillaryElectrophoresis: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology
    ) = ...  # static # readonly
    GasChromatography: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology
    ) = ...  # static # readonly
    LiquidChromatography: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology
    ) = ...  # static # readonly
    MassSpectrometry: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology
    ) = ...  # static # readonly
    Unknown: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology = (
        ...
    )  # static # readonly

class SignalInfo:  # Class
    def __init__(self, shortName: str) -> None: ...

    Channel: str  # readonly
    Detector: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType  # readonly
    DetectorInstance: int  # readonly
    DetectorName: str  # readonly
    Injector: str  # readonly
    Name: str  # readonly
    SeparationTechnology: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology
    )  # readonly

    def GetHashCode(self) -> int: ...
    @staticmethod
    def GetSeparationTechnology(
        detector: Agilent.OpenLab.Framework.DataAccess.CoreTypes.DetectorType,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.SeparationTechnology: ...
    @overload
    def Equals(self, obj: Any) -> bool: ...
    @overload
    def Equals(
        self, signalInfo: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SignalInfo
    ) -> bool: ...

class SignalInformation(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISignalInformation
):  # Class
    def __init__(
        self,
        msRawDataInformation: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsRawDataInformation,
    ) -> None: ...

    MSRawDataInformation: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsRawDataInformation
    )  # readonly

class SpectraData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData,
):  # Class
    def __init__(self) -> None: ...

    Data: Iterable[Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData]
    SpectraDescription: str
    SpectraName: str

    @overload
    def Shift(self, delta: float) -> None: ...
    @overload
    def Shift(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    def CountDataPoints(self) -> int: ...
    @overload
    def GetSpectrum(
        self, time: float
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    @overload
    def GetSpectrum(
        self,
        time: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    @overload
    def GetSpectrum(
        self,
        spectrumExtractionParameters: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExtractionParameters,
    ) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...
    def Clone(self) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectraData: ...

class SpectrumData(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IShiftableData,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ICloneableData[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData
    ],
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData,
):  # Class
    def __init__(
        self,
        data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData,
        xunit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit,
        yunit: str,
        time: Optional[float] = ...,
    ) -> None: ...

    Data: Agilent.OpenLab.Framework.DataAccess.CoreTypes.IData  # readonly
    Description: str
    ExprType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr
    MsAcquisitionDetails: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.IMsAcquisitionDetails
    )
    Name: str
    Time: Optional[float]  # readonly
    TimeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit
    XUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit  # readonly
    YUnit: str  # readonly

    @overload
    def Shift(
        self,
        delta: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> None: ...
    @overload
    def Shift(self, delta: float) -> None: ...
    def Clone(self) -> Agilent.OpenLab.Framework.DataAccess.CoreTypes.ISpectrumData: ...

class SpectrumExpr(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Apex: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    CancelPeak: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Downslope1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Downslope2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Emission: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Excitation: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    ForceBaseline: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    PeakAll: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    PeakBegin: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    PeakEnd: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Periodic: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    SmallPeakTop: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Undefined: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Unknown: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Upslope1: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Upslope2: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly
    Valley: Agilent.OpenLab.Framework.DataAccess.CoreTypes.SpectrumExpr = (
        ...
    )  # static # readonly

class SpectrumExtractionParameters(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.BaseExtractionParameters,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        unit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
        extractionTime: float,
    ) -> None: ...

    BackgroundSourceType: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.BackgroundSourceType
    )
    BackgroundTimeRanges: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeRange
    ]
    ForegroundTimeRanges: System.Collections.Generic.List[
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeRange
    ]
    LongDisplayString: str  # readonly
    MassWindow: float
    MaxExtractionTime: float
    MinExtractionTime: float
    MsExtractionParameters: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.MsExtractionParameters
    )
    ShortDisplayString: str  # readonly
    SimIonMass: float
    TimeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit

    @staticmethod
    def BuildLongDisplayString(
        minExtractionTime: float,
        maxExtractionTime: float,
        timeUnit: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit,
    ) -> str: ...
    @staticmethod
    def BuildShortDisplayString(maxExtractionTime: float) -> str: ...
    def Serialize(self) -> str: ...

class TimeRange:  # Struct
    def __init__(self, beginTime: float, endTime: float) -> None: ...

    BeginTime: float
    EndTime: float

    def GetHashCode(self) -> int: ...
    def Equals(self, obj: Any) -> bool: ...

class TimeUnit(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    Milliseconds: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit = (
        ...
    )  # static # readonly
    Minutes: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit = (
        ...
    )  # static # readonly
    Seconds: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit = (
        ...
    )  # static # readonly
    Unknown: Agilent.OpenLab.Framework.DataAccess.CoreTypes.TimeUnit = (
        ...
    )  # static # readonly

class UserLinkType:  # Class
    def __init__(self) -> None: ...

    Item: Any

class UvChromatogramExtractionParameters(
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.IExtractionParameters,
    Agilent.OpenLab.Framework.DataAccess.CoreTypes.BaseExtractionParameters,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        extractionType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType,
        minWavelength: float,
        maxWavelength: float,
        spectraDetectorName: str,
        spectraDetectorInstance: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        extractionType: Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType,
        spectraDetectorName: str,
        spectraDetectorInstance: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        wavelength: float,
        bandwidth: float,
        spectraDetectorName: str,
        spectraDetectorInstance: int,
    ) -> None: ...
    @overload
    def __init__(
        self,
        wavelength: float,
        bandwidth: float,
        referenceWavelength: float,
        referenceBandwidth: float,
        spectraDetectorName: str,
        spectraDetectorInstance: int,
    ) -> None: ...

    Bandwidth: float
    ExtractionType: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType
    )
    LongDisplayString: str  # readonly
    MaxWavelength: float
    MinWavelength: float
    RefBandwidth: float
    RefWavelength: float
    ShortDisplayString: str  # readonly
    SpectraDetectorInstance: int
    SpectraDetectorName: str
    UseReference: bool
    Wavelength: float

    def Serialize(self) -> str: ...

class UvChromatogramExtractionType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    ExtractedWavelengthChromatogram: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType
    ) = ...  # static # readonly
    MaxWavelengthChromatogram: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType
    ) = ...  # static # readonly
    TotalWavelengthChromatogram: (
        Agilent.OpenLab.Framework.DataAccess.CoreTypes.UvChromatogramExtractionType
    ) = ...  # static # readonly

class ValueBaseType:  # Class
    def __init__(self) -> None: ...

    DeclaringType: System.Type  # readonly
    HasResourceContext: bool  # readonly
    PropertyName: str  # readonly

    def SetResourceContext(
        self, runTimeDeclaringType: System.Type, runTimePropertyName: str
    ) -> None: ...

class XUnit(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    MassToCharge: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
    Milliseconds: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
    Minutes: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
    Nanometer: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
    Seconds: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
    Unknown: Agilent.OpenLab.Framework.DataAccess.CoreTypes.XUnit = (
        ...
    )  # static # readonly
